@@ -6,6 +6,7 @@
 #include <stdio.h>
 #include <string.h>
 //#include <gst/gst.h>
+//#include <SDL/SDL_mixer.h>
 
 #include "../../Pico/PicoInt.h"
 #include "../../Pico/sound/mix.h"
@@ -16,13 +17,14 @@ static short mp3_out_buffer[2*1152];
 static HMP3Decoder mp3dec = 0;
 static int mp3_buffer_offs = 0;
 
+//static Mix_Music* music = NULL;
 
 //static GstElement* pipeline = NULL;
 
 static int try_get_header(unsigned char *buff, MP3FrameInfo *fi)
 {
 	int ret, offs1, offs = 0;
-
+/*
 	while (1)
 	{
 		offs1 = MP3FindSyncWord(buff + offs, 2048 - offs);
@@ -36,12 +38,12 @@ static int try_get_header(unsigned char *buff, MP3FrameInfo *fi)
 		if (ret == 0 && fi->bitrate != 0) break;
 		offs++;
 	}
-
+*/
 	return ret;
 }
 
-int mp3_get_bitrate(FILE *f, int len)
-{
+int mp3_get_bitrate(char *ff, int len)
+{/*
 	unsigned char buff[2048];
 	MP3FrameInfo fi;
 	int ret;
@@ -50,7 +52,7 @@ int mp3_get_bitrate(FILE *f, int len)
 
 	if (!mp3dec) mp3dec = MP3InitDecoder();
 
-	//FILE* f = fopen( ff, "r" );
+	FILE* f = fopen( ff, "r" );
 	if( !f ) return -1;
 
 	fseek(f, 0, SEEK_SET);
@@ -69,8 +71,10 @@ int mp3_get_bitrate(FILE *f, int len)
 	if (ret != 0) { fclose(f); return ret; }
 
 	//printf("bitrate: %i\n", fi.bitrate / 1000);
+	fclose(f);
 
-	return fi.bitrate / 1000;
+	return fi.bitrate / 1000;*/
+	return 256;
 }
 
 
@@ -137,7 +141,7 @@ static int mp3_decode(void)
 	int bytesLeft;
 	int offset; // mp3 frame offset from readPtr
 	int err;
-
+/*
 	do
 	{
 		if (mp3_file_pos >= mp3_file_len) return 1; // EOF, nothing to do
@@ -176,7 +180,7 @@ static int mp3_decode(void)
 		mp3_file_pos += readPtr - mp3_input_buffer;
 	}
 	while (0);
-
+*/
 	return 0;
 }
 /*
@@ -203,11 +207,25 @@ static gboolean bus_call(GstBus *bus, GstMessage *msg, gpointer data) {
 
 extern GMainLoop* g_loop;
 */
-void mp3_start_play(FILE *f, int pos)
-{/*
-	gst_init( NULL, NULL );
+extern void maemo_play_music( char* file, int pos );
 
-	printf( "Playing CD Track %s\n", f );
+void mp3_start_play(char *f, int pos)
+{
+	maemo_play_music(f,pos);
+	/*if( music ) {
+		Mix_PauseMusic();
+		Mix_FreeMusic( music );
+		music = NULL;
+	}*/
+	/*music = Mix_LoadMUS( f );
+	if( music ) {
+		if( Mix_PlayMusic( music, 1 ) == -1 )
+			printf( "Error playing mp3: %s\n", Mix_GetError() );
+	} else {
+		printf( "Error loading mp3: %s\n", Mix_GetError() );
+	}*/
+
+	/*printf( "Playing CD Track %s\n", f );
 	GError* error = NULL;
 
 	if( pipeline ) {
@@ -215,28 +233,23 @@ void mp3_start_play(FILE *f, int pos)
 		gst_object_unref( GST_OBJECT(pipeline) );
 	}
 
-	GstElement* filesrc = gst_element_factory_make( "filesrc", NULL );
-	if( !filesrc ) { printf( "Error creating filesrc\n" ); return; }
-	GstElement* parser = gst_element_factory_make( "mp3parse", NULL );
-	if( !filesrc ) { printf( "Error creating parser\n" ); return; }
-	GstElement* decoder = gst_element_factory_make( "nokiamp3dec", NULL );
-	if( !filesrc ) { printf( "Error creating decoder\n" ); return; }
-	GstElement* sink = gst_element_factory_make( "pulsesink", NULL );
-	if( !filesrc ) { printf( "Error creating sink\n" ); return; }
-	pipeline = gst_pipeline_new( "audio-player" );
-	g_object_set( G_OBJECT(filesrc), "location", f, NULL );
-	GstBus* bus = gst_pipeline_get_bus( GST_PIPELINE(pipeline) );
-	gst_bus_add_watch( bus, bus_call, g_loop );
-	gst_object_unref( bus );
-	gst_bin_add_many( GST_BIN(pipeline), filesrc, parser, decoder, sink, NULL );
-	if( gst_element_link_many( filesrc, parser, decoder, sink, NULL ) ) printf( "Link succeeded\n" ); else printf( "Link failed\n" );
+	pipeline = gst_parse_launch( "filesrc name=mp3file ! mp3parse ! nokiamp3dec ! pulsesink", &error );
+	if( !pipeline ) printf( "Error tope de gordo!!\n" );
+	if( error ) {
+		printf( "Error creating pipeline: %s\n", error->message );
+	}
+	GstElement* filesrc = gst_bin_get_by_name( GST_BIN(pipeline), "mp3file" );
+	g_object_set( G_OBJECT(filesrc), "location", "/home/user/MyDocs/ROMS/megadrive/soniccd/Sonic CD 26.mp3", NULL );
+	//GstBus* bus = gst_pipeline_get_bus( GST_PIPELINE(pipeline) );
+	//gst_bus_add_watch( bus, bus_call, g_loop );
+	//gst_object_unref( bus );
 
 	printf( "About to play...\n" );
 	gst_element_set_state( pipeline, GST_STATE_PLAYING );
 	printf( "Play MP3 successful\n" );
 	return;
-	*/
-	mp3_file_len = mp3_file_pos = 0;
+*/
+	/*mp3_file_len = mp3_file_pos = 0;
 	mp3_current_file = NULL;
 	mp3_buffer_offs = 0;
 
@@ -257,7 +270,7 @@ void mp3_start_play(FILE *f, int pos)
 		//mp3_file_pos = pos;
 	}
 
-	mp3_decode();
+	mp3_decode();*/
 }
 
 int mp3_get_offset(void)
@@ -282,7 +295,7 @@ int mp3_get_offset(void)
 
 void mp3_update(int *buffer, int length, int stereo)
 {
-
+/*
 	int length_mp3, shr = 0;
 	void (*mix_samples)(int *dest_buf, short *mp3_buf, int count) = mix_16h_to_32;
 
@@ -308,7 +321,7 @@ void mp3_update(int *buffer, int length, int stereo)
 			mix_samples(buffer + ((left>>shr)<<1), mp3_out_buffer, (mp3_buffer_offs>>shr)<<1);
 		} else
 			mp3_buffer_offs = 0;
-	}
+	}*/
 }
 
 
