@@ -13,11 +13,13 @@ enum TPicoGameState {
 	PGS_ReloadRomState,
 	PGS_Menu,
 	PGS_RestartRun,
+	PGS_QuickSave,
+	PGS_QuickLoad
 };
 
 extern char romFileName[];
 extern int engineState;
-
+extern int quickSlot;
 
 void emu_Init(void);
 void emu_Deinit(void);
@@ -27,6 +29,8 @@ void emu_forcedFrame(void);
 void emu_set_state( int state );
 void emu_load_snapshot();
 void emu_save_snapshot();
+void emu_quicksave( int slot );
+void emu_quickload( int slot );
 
 void osd_text(int x, int y, const char *text);
 
